#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-BoPrX3BrK7O27KWG8tcUP9
key:                  persistent-test-2.13.1.3-BoPrX3BrK7O27KWG8tcUP9
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  dc8e71e2eea13bcf38183e85ed98e3c5
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-BoPrX3BrK7O27KWG8tcUP9
depends:
    HUnit-1.6.2.0-7daynvgJ9gn4o0bEK8hQoK
    QuickCheck-2.15.0.1-3QPJ8ldUhsWJNtRWRJrsjE
    aeson-2.2.1.0-Def4REbZAAu5MJxZQtCFDo base-4.18.2.1
    blaze-html-0.9.2.0-5KOFvxYdO0n8Klfhjp0zuJ bytestring-0.11.5.3
    conduit-1.3.6.1-33PyKFsamc3EFWlmJ7D0Br containers-0.6.7
    exceptions-0.10.7 hspec-2.11.5-IV5iN083zs8FAN90zbwfvE
    hspec-expectations-0.8.4-5112mJLH3jZ7l90kwWBITq
    http-api-data-0.6.1-IBOPMFBdzGt5s1N5d0VKvX
    monad-control-1.0.3.1-3rDqCqBwApu6XpK1g6fhm1
    monad-logger-0.3.42-Gz3nX5p8fJ29HPLriRpUQl mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-FAwgt6nNomG3D4QE8cObIU
    quickcheck-instances-0.3.33-HRb0mKUFqi7Ek0QgF38xBp
    random-1.2.1.3-Lrunn7lr3eYBt1jhWQyV5S
    resourcet-1.2.6-A7WR33a0Ijp2wXAvSf2FKK text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-4jVW4Rh31cKIdkBGu8jR29
    unliftio-0.2.25.1-2YWCJQ4bXOaKV2dFmJlGMH
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

